==> alicevision_3.2.0+repack.orig.tar.xz: AliceVision-3.2.0/CONTRIBUTORS.md <==
AliceVision Contributors
========================

The project is released under [MPLv2](LICENSE-MPL2.md).

Individuals
-----------

- Abdelrahman Al Marouk
- Candice Bentejac
- Carsten Griwodz
- Cenek Albl
- Clement Aymard
- Clement Debize
- Cyril Pichard
- Enguerrand De Smet
- Fabien Castan
- Fabien Servant
- Gregoire De Lillo
- Havard Espeland
- Jean Melou
- Julien Haudegond
- Lilian Calvet
- Loic Vital
- Michal Polic
- Nicolas Rondaud
- Pierre Gurdjos
- Povilas Kanapickas
- Simone Gasparini
- Théo Leplomb
- Tomas Pajdla
- Vincent Demoulin
- Yann Lanthony
- Zeljko Vrba

Institutions
------------

- Czech Technical University (CTU) in Prague, Czech Republic  
  http://cmp.felk.cvut.cz
- Institut National Polytechnique de Toulouse (Toulouse INP), France  
  http://www.inp-toulouse.fr
- Mikros Image, Post-Production Company in Paris, France  
  http://www.mikrosimage.com
- Simula Research Laboratory AS in Oslo, Norway  
  https://www.simula.no
- Quine in Oslo, Norway  
  http://www.quine.no
- This project has received funding from the European Union’s Horizon 2020 research and innovation programme  
  [POPART](http://www.alicevision.org/popart) and [LADIO](http://www.alicevision.org/ladio).


CMPMVS Contributors
===================

[CMPMVS](http://people.ciirc.cvut.cz/~pajdla/) has been the first step to build the AliceVision MVS pipeline.
This part was CTU proprietary solution.

Individuals
-----------

- Cenek Albl
- Michal Jancosek
- Tomas Pajdla

Institutions
------------

- Czech Technical University (CTU) in Prague, Czech Republic
  http://cmp.felk.cvut.cz


OpenMVG Contributors
====================

[openMVG](https://github.com/openMVG/openMVG) has been the first step to build the AliceVision SfM pipeline.
This part was released under [MPLv2](LICENSE-MPL2.md).

Individuals
-----------

- anhtuann
- Bruno Duisit
- cdcseacave
- Chris Sweeney
- Iivari Aikas
- Kevin Cain
- Kyle Wilson
- luxigo
- Michael Holroyd
- Pascal Monasse
- Pierre Moulon
- Renaud Marlet
- rhiestan
- Romain Janvier
- Romuald Perrot
- Rory McCann
- Sergi Pujades-Rocamora
- Stephane Flotron
- vincentweb
- Yohann Salaun

Institutions
------------
- IMAGINE from the Universite Paris Est, LIGM Gaspard-Monge, France
  http://imagine.enpc.fr
- Mikros Image, Post-Production Company in Paris, France
  http://www.mikrosimage.com


libmv Contributors
==================

[libmv](https://github.com/libmv/libmv) has been an important source of inspiration for the design of the SfM modules and part of the code from the "multiview" and "robustEstimation" modules are based on libmv code and continue to evolve.
This part was released under [MIT](LICENSE-MIT-libmv.md).

- Andrew Chant <andrew.chant@gmail.com>
- Daniel Waterworth <da.waterworth@gmail.com>
- Darius Blaszyk <dblaszyk@gmail.com>
- David Roberts <dvdr18@gmail.com>
- Jose Gonzalez <de0a100@gmail.com>
- Julien Michot <julien.michot.fr@gmail.com>
- Keir Mierle <mierle@gmail.com>
- Marco Molteni <marco.molteni@laposte.net>
- Matthias Fauconneau <matthias.fauconneau@gmail.com>
- Nathan Wiegand <nathanwiegand@gmail.com>
- Pau Gargallo <pau.gargallo@gmail.com>
- Pierre Moulon <pmoulon@gmail.com>
- Rehno Lindeque <errantkid@gmail.com>
- Slava Vishnyakov <bomboze@gmail.com>
- Vess Perfanov <vessper@gmail.com>
- W. James MacLean <w.james.maclean@gmail.com>

==> alicevision_3.3.1+repack.orig.tar.xz: AliceVision-3.3.1/CONTRIBUTORS.md <==
AliceVision Contributors
========================

The project is released under [MPLv2](LICENSE-MPL2.md).

Individuals
-----------

- Abdelrahman Al Marouk
- Alice Sonolet
- balloonalpha
- Candice Bentejac
- Carsten Griwodz
- Cedric Thebault
- Cenek Albl
- c-ewing
- Clement Aymard
- Clement Debize
- Cyril Pichard
- Enguerrand De Smet
- Fabien Castan
- Fabien Servant
- Gregoire De Lillo
- Havard Espeland
- JackBoosY
- Jean Melou
- Julien Haudegond
- Lilian Calvet
- Loic Vital
- luzpaz
- Michal Polic
- Matthieu Hog
- Nicolas Rondaud
- Pierre Gurdjos
- Povilas Kanapickas
- Simone Gasparini
- Sylvain Maziere
- Théo Leplomb
- Tomas Pajdla
- Vincent Demoulin
- Yann Lanthony
- Zeljko Vrba

Institutions
------------

- Czech Technical University (CTU) in Prague, Czech Republic  
  http://cmp.felk.cvut.cz
- Institut National Polytechnique de Toulouse (Toulouse INP), France  
  http://www.inp-toulouse.fr
- Mikros Image, Post-Production Company in Paris, France  
  http://www.mikrosimage.com
- Simula Research Laboratory AS in Oslo, Norway  
  https://www.simula.no
- Quine in Oslo, Norway  
  http://www.quine.no
- This project has received funding from the European Union’s Horizon 2020 research and innovation programme  
  [POPART](http://www.alicevision.org/popart) and [LADIO](http://www.alicevision.org/ladio).


CMPMVS Contributors
===================

[CMPMVS](http://people.ciirc.cvut.cz/~pajdla/) has been the first step to build the AliceVision MVS pipeline.
This part was CTU proprietary solution.

Individuals
-----------

- Cenek Albl
- Michal Jancosek
- Tomas Pajdla

Institutions
------------

- Czech Technical University (CTU) in Prague, Czech Republic
  http://cmp.felk.cvut.cz


OpenMVG Contributors
====================

[openMVG](https://github.com/openMVG/openMVG) has been the first step to build the AliceVision SfM pipeline.
This part was released under [MPLv2](LICENSE-MPL2.md).

Individuals
-----------

- anhtuann
- Bruno Duisit
- cdcseacave
- Chris Sweeney
- Iivari Aikas
- Kevin Cain
- Kyle Wilson
- luxigo
- Michael Holroyd
- Pascal Monasse
- Pierre Moulon
- Renaud Marlet
- rhiestan
- Romain Janvier
- Romuald Perrot
- Rory McCann
- Sergi Pujades-Rocamora
- Stephane Flotron
- vincentweb
- Yohann Salaun

Institutions
------------
- IMAGINE from the Universite Paris Est, LIGM Gaspard-Monge, France
  http://imagine.enpc.fr
- Mikros Image, Post-Production Company in Paris, France
  http://www.mikrosimage.com


libmv Contributors
==================

[libmv](https://github.com/libmv/libmv) has been an important source of inspiration for the design of the SfM modules and part of the code from the "multiview" and "robustEstimation" modules are based on libmv code and continue to evolve.
This part was released under [MIT](LICENSE-MIT-libmv.md).

- Andrew Chant <andrew.chant@gmail.com>
- Daniel Waterworth <da.waterworth@gmail.com>
- Darius Blaszyk <dblaszyk@gmail.com>
- David Roberts <dvdr18@gmail.com>
- Jose Gonzalez <de0a100@gmail.com>
- Julien Michot <julien.michot.fr@gmail.com>
- Keir Mierle <mierle@gmail.com>
- Marco Molteni <marco.molteni@laposte.net>
- Matthias Fauconneau <matthias.fauconneau@gmail.com>
- Nathan Wiegand <nathanwiegand@gmail.com>
- Pau Gargallo <pau.gargallo@gmail.com>
- Pierre Moulon <pmoulon@gmail.com>
- Rehno Lindeque <errantkid@gmail.com>
- Slava Vishnyakov <bomboze@gmail.com>
- Vess Perfanov <vessper@gmail.com>
- W. James MacLean <w.james.maclean@gmail.com>
